summaryrefslogtreecommitdiff
path: root/sys
diff options
context:
space:
mode:
authorMark Kettenis <kettenis@cvs.openbsd.org>2007-01-09 22:37:19 +0000
committerMark Kettenis <kettenis@cvs.openbsd.org>2007-01-09 22:37:19 +0000
commitbeeb0337b6370731d3379f74e2968979b30aa5d7 (patch)
tree9f522bfe188cbfc2409a95b145da735e5c30229b /sys
parent001ceeb315d68e33d0c04b7206f369d9017ed3aa (diff)
Adjust for USIII to RIO EBus renaming.
Diffstat (limited to 'sys')
-rw-r--r--sys/arch/sparc64/dev/ebus.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/sys/arch/sparc64/dev/ebus.c b/sys/arch/sparc64/dev/ebus.c
index 4368d3067f9..a28a6ceb58d 100644
--- a/sys/arch/sparc64/dev/ebus.c
+++ b/sys/arch/sparc64/dev/ebus.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: ebus.c,v 1.14 2006/06/27 20:20:48 jason Exp $ */
+/* $OpenBSD: ebus.c,v 1.15 2007/01/09 22:37:18 kettenis Exp $ */
/* $NetBSD: ebus.c,v 1.24 2001/07/25 03:49:54 eeh Exp $ */
/*
@@ -128,10 +128,10 @@ ebus_match(struct device *parent, void *match, void *aux)
strcmp(name, "ebus") == 0)
return (1);
/* Or a real ebus III */
if (PCI_CLASS(pa->pa_class) == PCI_CLASS_BRIDGE &&
PCI_VENDOR(pa->pa_id) == PCI_VENDOR_SUN &&
- PCI_PRODUCT(pa->pa_id) == PCI_PRODUCT_SUN_EBUSIII &&
+ PCI_PRODUCT(pa->pa_id) == PCI_PRODUCT_SUN_RIO_EBUS &&
strcmp(name, "ebus") == 0)
return (1);
@@ -128,10 +128,10 @@ ebus_match(struct device *parent, void *match, void *aux)
strcmp(name, "ebus") == 0)
return (1);
- /* Or a real ebus III */
+ /* Or a real RIO ebus */
if (PCI_CLASS(pa->pa_class) == PCI_CLASS_BRIDGE &&
PCI_VENDOR(pa->pa_id) == PCI_VENDOR_SUN &&